==> resource_planner-0.2.2.gem: app/assets/javascripts/resource_planner/reccuring_event_form.js <==
var formData = {};
var iCalData = {};

$(document).ready(function () {
  $("table.recurring_event_data.no_repeat").show(); //'slow');
  var selected_recurrence = $("select#resource_planner_event_rrule").val();

  clearFields(selected_recurrence);       // clear all fields of previous screens...

  //
  // common fields
  //

  // title
  $('#title').on('change', function () {
    formUpdateHandler();
  });

  $('#title').on('input', function () {
    formUpdateHandler();
  });

  // description
  $('#description').on('change', function () {
    formUpdateHandler();
  });

  $('#description').on('input', function () {
    formUpdateHandler();
  });

  // start_date
  $('#start_date').on('change', function () {
    formUpdateHandler();
  });

  $('#start_date').on('input', function () {
    formUpdateHandler();
  });

  $('#resource_planner_event_dtstart_timezone').on('change', function () {
    formUpdateHandler();
  });

  $('#resource_planner_event_dtstart_timezone').on('input', function () {
    formUpdateHandler();
  });

  // duration
  $('#duration').on('change', function () {
    formUpdateHandler();
  });

  $('#duration').on('input', function () {
    formUpdateHandler();
  });

  $('#duration_units').on('change', function () {
    formUpdateHandler();
  });

  // resource_planner_event_rrule
  $('#resource_planner_event_rrule').on('change', function () {
    formUpdateHandler();
  });

  $('#resource_planner_event_rrule').on('input', function () {
    formUpdateHandler();
  });


  //
  // no_repeat fields
  //

  // end_date
  $('#end_date').on('change', function () {
    formUpdateHandler();
  });

  $('#end_date').on('input', function () {
    formUpdateHandler();
  });

  $('#resource_planner_event_dtend_timezone').on('change', function () {
    formUpdateHandler();
  });

  $('#resource_planner_event_dtend_timezone').on('input', function () {
    formUpdateHandler();
  });


  //
  // reccurence_pattern fields
  //
  $('.day_buttons label').on('click', function () {
    var checkbox = $(this).prev('input:checkbox:first');
    if (checkbox.is(':checked')) {
      // it is currently checked, un-ckeck it
      checkbox.prop("checked", false);
      $(this).removeClass('day-button-selected');
    } else {
      // it is currently un-checked, ckeck it
      checkbox.prop("checked", true);
      $(this).addClass('day-button-selected');
    }
  });

  $('.monthly_day_buttons label').on('click', function () {
    var checkbox = $(this).prev('input:checkbox:first');
    if (checkbox.is(':checked')) {
      // it is currently checked, un-ckeck it
      checkbox.prop("checked", false);
      $(this).removeClass('day-button-selected');
    } else {
      // it is currently un-checked, ckeck it
      checkbox.prop("checked", true);
      $(this).addClass('day-button-selected');
    }
  });

  $('.recurring_event_data input').on('change', function () {
    formUpdateHandler();
  });
  //$('.recurring_event_data input').on('input', function () {
  //  formUpdateHandler();
  //});
  $('.recurring_event_data label').on('click', function () {
    formUpdateHandler();
  });


  //
  // range_of_reccurence fields
  //
  $('.range_of_reccurence input').on('change', function () {
    formUpdateHandler();
  });
  //$('.range_of_reccurence input').on('input', function () {
  //  formUpdateHandler();
  //});


  // Submit button handler
  $('input[type=submit]').on('click', function () {
    submitButtonHandler();
  });

  // Initialise...
  formUpdateHandler();
});

$(function () {
  $(document).on("change", "select#resource_planner_event_rrule", function () {
    $("table.recurring_event_data").hide(); //'slow');
    $("table.range_of_reccurence").hide(); //'slow');

    var selected_recurrence = $("select#resource_planner_event_rrule").val();
    clearFields(selected_recurrence);       // clear all fields of previous screens...
    if (selected_recurrence) {
      $("table.recurring_event_data." + selected_recurrence).show(); //'slow');
      if (selected_recurrence !== "no_repeat") {
        $("table.range_of_reccurence").show(); //'slow');
      }
    }

    window.startingDate = $.trim($("#start_date").val());
    if (window.startingDate == "") {
      window.startingDate = moment().format();
      $.trim($("#start_date").val(moment(window.startingDate).format()));
    }
    window.endingDate = window.startingDate;
    updateTimelineDuration(window.startingDate, window.endingDate);
    //updateTimelineDuration(window.startingDate, window.endingDate);

    return false;
  });

  //$(".day_buttons").buttonset();

  /* commented out for test - 29.12.2018
  $(document).on("click", ".day_buttons label", function(event) {
    //alert($(this).text() + ' clicked');
    var checkbox = $(this).prev('input:checkbox:first');
    if (checkbox.is(':checked')) {
      checkbox.prop("checked", false);
      $(this).removeClass('day-button-selected');
    } else {
      checkbox.prop("checked", true);
      $(this).addClass('day-button-selected');
    }
    return false;
  });
  // commented out for test - 29.12.2018 */

  //$(document).on("change", ".day_buttons input", function(event) {
  //  alert($(this).is(':checked'));
  //  if ($(this).is(':checked')) {
  //    $(this).closest('label').addClass('day-button-selected');
  //  } else {
  //    $(this).closest('label').removeClass('day-button-selected');
  //  }
  //  return false;
  //});


  //$(".monthly_day_buttons").buttonset();
  /*
  $(document).on("click", ".monthly_day_buttons label", function(event) {
    //alert($(this).text() + ' clicked');
    var checkbox = $(this).prev('input:checkbox:first');
    if (checkbox.is(':checked')) {
      checkbox.prop("checked", false);
      $(this).removeClass('day-button-selected');
    } else {
      checkbox.prop("checked", true);
      $(this).addClass('day-button-selected');
    }
    return false;
  });
*/

  //$(document).on("change", ".monthly_day_buttons input", function(event) {
  //  alert($(this).is(':checked'));
  //  if ($(this).is(':checked')) {
  //    $(this).closest('label').addClass('day-button-selected');
  //  } else {
  //    $(this).closest('label').removeClass('day-button-selected');
  //  }
  //  return false;
  //});

});

// Capture form fields -> 'window' data
function formUpdateHandler() {
  captureFormData();
  //validateFormData();
  updateIcalData();
  //prepareEventsArray();
  //renderEvents();
}

/**
 * Capture form fields -> formData
 */
function captureFormData() {

  formData.title = $.trim($('#title').val());
  formData.description = $.trim($('#description').val());

  formData.start_date = $.trim($('#start_date').val());
  formData.resource_planner_event_dtstart_timezone = $.trim($('#resource_planner_event_dtstart_timezone').val());

  formData.duration = $.trim($('#duration').val());
  formData.duration_units = $.trim($('#duration_units').val());

  formData.resource_planner_event_rrule = $.trim($('#resource_planner_event_rrule').val());

  // no_repeat fields
  formData.end_date = $.trim($('#end_date').val());
  formData.resource_planner_event_dtend_timezone = $.trim($('#resource_planner_event_dtend_timezone').val());

  // daily fields
  formData.resource_planner_event_count_every_n_days = $('#resource_planner_event_count_every_n_days')[0].checked;
  formData.resource_planner_event_count_every_weekday = $('#resource_planner_event_count_every_weekday')[0].checked;
  formData.resource_planner_event_count = $.trim($('#resource_planner_event_count').val());

  // weekly fields
  //resource_planner_event_count (See above.... In the 'weekly' case, it always refers to 'every n weeks')
  var selected_weekdays = '';
  $('.recurring_event_data.weekly .day_buttons input[type=checkbox]').each(function (index) {
    if ($(this)[0].checked) {
      var name = $(this)[0].name;
      var day = name.substring(name.lastIndexOf("[") + 1, name.lastIndexOf("]"));
      selected_weekdays = selected_weekdays + day + '/';
    }
  });
  formData.selected_weekdays = selected_weekdays.substring(0, selected_weekdays.length - 1);


  // monthly fields
  formData.resource_planner_event_count_every_month = $('#resource_planner_event_count_every_month')[0].checked;
  //resource_planner_event_count (See above.... In the 'monthly' case, it always refers to 'every n months')
  formData.resource_planner_event_bymonthday = $.trim($('#resource_planner_event_bymonthday').val());
  formData.resource_planner_event_bymonthday_day = $.trim($('#resource_planner_event_bymonthday_day').val());

  formData.resource_planner_event_count_every_month_day = $('#resource_planner_event_count_every_month_day')[0].checked;
  var selected_days_of_month = '';
  $('.recurring_event_data.monthly .monthly_day_buttons input[type=checkbox]').each(function (index) {
    if ($(this)[0].checked) {
      var name = $(this)[0].name;
      var date = name.substring(name.lastIndexOf("[") + 1, name.lastIndexOf("]"));
      selected_days_of_month = selected_days_of_month + date + '/';
    }
  });
  formData.selected_days_of_month = selected_days_of_month.substring(0, selected_days_of_month.length - 1);


  // range_of_reccurence fields
  formData.resource_planner_event_until_no_end_date = $('#resource_planner_event_until_no_end_date')[0].checked;
  formData.resource_planner_event_until_create_n_events = $('#resource_planner_event_until_create_n_events')[0].checked;
  formData.resource_planner_event_until_count = $.trim($('#resource_planner_event_until_count').val());
  formData.resource_planner_event_until_repeat_until = $('#resource_planner_event_until_repeat_until')[0].checked;
  formData.repeat_until = $.trim($('#repeat_until').val());

  //console.clear();
  console.log('formData:');
  console.log(formData);
}

/**
 * Convert formData into iCalData
 */
function updateIcalData() {
  // This could be performed on the server-side
}

// Submit button
function submitButtonHandler() {

  // Collect resource data
  var resource_list = '';
  var resources = [];
  $('.fc-resource-area [data-resource-id]').each(function () {
    var resource_id = $(this).attr('data-resource-id');
    var unselected_background_color = 'rgba(0, 0, 0, 0)';

    var selected = ($(this).find('.fc-widget-content').css('background-color') != unselected_background_color);
    if (selected) {
      resource_list += resource_id + "\n";
      resources.push(resource_id);

    }
  });

  // Show summary
  var msg = "Event will be created:\n" +
    "Start    :" + formData.start_date + "(" + window.startingDate + ")\n" +
    "End      :" + formData.end_date + "(" + window.endingDate + ")\n" +
    "Resources:\n" +
    resource_list;
  alert(msg);
  //alertDialog.show(msg);

  var data = {};
  data.formData = formData;
  data.resources = resources;
  data.eventsArray = eventsArray;

  // //Passing mdate and phone variables to rails controller(book_date & phone)
  // window.open("localhost:3000//controller/create?mdate="+mdate+"&phone="+phone,"_self")
  //
  // -- OR --
  //
  /* Send the data using post */
  $.ajax({
    url: '/resource_planner/events',
    type: 'POST',
    data: JSON.stringify(data),
    contentType: 'application/json',
    success: function (data, textStatus, jqXHR) {
      //alert('Complete: ' + textStatus);
      $('#fullcalendar_scheduler').fullCalendar('render');
    },
    error: function (data, textStatus, jqXHR) {
      //alert('Error: ' + textStatus);
      $('#fullcalendar_scheduler').fullCalendar('render');
    }
  });
  //
  // -- OR --
  //
  // // construct an HTTP request
  // var xhr = new XMLHttpRequest();
  // xhr.open(form.method, form.action, true);
  // xhr.setRequestHeader('Content-Type', 'application/json; charset=UTF-8');
  //
  // // send the collected data as JSON
  // xhr.send(JSON.stringify(data));
  //
  // xhr.onloadend = function () {
  //   // done
  // };
  //

}


//================================================================================================
function clearFields(selected_recurrence) { // clear all fields of previous screens...

  $('.highlighter').remove();
  $('#highlighter').remove();

  window.startingDate = undefined;
  window.endingDate = undefined;
  window.eventsArray = [];

  //var start_date = new Date(start_date).yyyymmdd();
  var start_date = $.trim($("#start_date").val());
  if (start_date == "") {
    $("#start_date").addClass("input_warning");
  } else {
    $("#start_date").removeClass("input_warning");
  }

  $.trim($("#duration").val(""));
  if (selected_recurrence !== "no_repeat") {
    $("#duration").addClass("input_warning");
    $("table.range_of_reccurence").show(); //'slow');
  } else {
    $.trim($("#duration").val(""));
    $.trim($("#end_date").val(""));
    $("#duration").addClass("input_warning");
    $("#end_date").addClass("input_warning");
  }

  // Clear DAILY Fields
  var buttonChecked = $('.recurring_event_data.daily input#resource_planner_event_count_every_n_days');
  buttonChecked[0].checked = false;
  $('.recurring_event_data.daily input#resource_planner_event_count').val("");
  buttonChecked = $('.recurring_event_data.daily input#resource_planner_event_count_every_weekday');
  buttonChecked[0].checked = false;

  //$(".recurring_event_data.daily").removeClass("input_warning");
  $(".recurring_event_data.daily").addClass("input_warning");

  // Clear WEEKLY Fields
  $('.recurring_event_data.weekly input').val("");

  $('.recurring_event_data.weekly .day_buttons input[type=checkbox]').each(function (index) {
    $(this)[0].checked = false;
  });
  $('.day-button-selected').removeClass('day-button-selected');

  //$(".recurring_event_data.weekly").removeClass("input_warning");
  $(".recurring_event_data.weekly").addClass("input_warning");

  // Clear MONTHLY Fields
  buttonChecked = $('.recurring_event_data.monthly input#resource_planner_event_count_every_month');
  buttonChecked[0].checked = false;
  $('.recurring_event_data.monthly input#resource_planner_event_count').val("");
  var selectedCheckedButton = $('.recurring_event_data.monthly input#resource_planner_event_count_every_month_day');   // is the day_of_month button checked ?
  selectedCheckedButton[0].checked = false;

  $('.recurring_event_data.monthly .monthly_day_buttons input[type=checkbox]').each(function (index) {
    $(this)[0].checked = false;
  });
  var selectedMonthDays = $('.recurring_event_data.monthly label.day-button-selected');
  selectedMonthDays.removeClass('day-button-selected');

  //$(".recurring_event_data.monthly").removeClass("input_warning");
  $(".recurring_event_data.monthly").addClass("input_warning");

  document.getElementById("resource_planner_event_until_no_end_date").checked = false;
  document.getElementById("resource_planner_event_until_create_n_events").checked = false;
  $("#resource_planner_event_until_count").val("");
  //$("#repeat_until").val("");
  document.getElementById("resource_planner_event_until_repeat_until").checked = false;
  //$(".range_of_reccurence").removeClass("input_warning");
  $(".range_of_reccurence").addClass("input_warning");

}                                          // clear all fields of previous screens...

==> resource_planner-0.2.4.gem: app/assets/javascripts/resource_planner/reccuring_event_form.js <==
var formData = {};
var iCalData = {};

$(document).ready(function () {
  $("table.recurring_event_data.no_repeat").show(); //'slow');
  var selected_recurrence = $("select#resource_planner_event_rrule").val();

  clearFields(selected_recurrence);       // clear all fields of previous screens...

  //
  // common fields
  //

  // title
  $('#title').on('change', function () {
    formUpdateHandler();
  });

  $('#title').on('input', function () {
    formUpdateHandler();
  });

  // description
  $('#description').on('change', function () {
    formUpdateHandler();
  });

  $('#description').on('input', function () {
    formUpdateHandler();
  });

  // start_date
  $('#start_date').on('change', function () {
    formUpdateHandler();
  });

  $('#start_date').on('input', function () {
    formUpdateHandler();
  });

  $('#resource_planner_event_dtstart_timezone').on('change', function () {
    formUpdateHandler();
  });

  $('#resource_planner_event_dtstart_timezone').on('input', function () {
    formUpdateHandler();
  });

  // duration
  $('#duration').on('change', function () {
    formUpdateHandler();
  });

  $('#duration').on('input', function () {
    formUpdateHandler();
  });

  $('#duration_units').on('change', function () {
    formUpdateHandler();
  });

  // resource_planner_event_rrule
  $('#resource_planner_event_rrule').on('change', function () {
    formUpdateHandler();
  });

  $('#resource_planner_event_rrule').on('input', function () {
    formUpdateHandler();
  });


  //
  // no_repeat fields
  //

  // end_date
  $('#end_date').on('change', function () {
    formUpdateHandler();
  });

  $('#end_date').on('input', function () {
    formUpdateHandler();
  });

  $('#resource_planner_event_dtend_timezone').on('change', function () {
    formUpdateHandler();
  });

  $('#resource_planner_event_dtend_timezone').on('input', function () {
    formUpdateHandler();
  });


  //
  // reccurence_pattern fields
  //
  $('.day_buttons label').on('click', function () {
    var checkbox = $(this).prev('input:checkbox:first');
    if (checkbox.is(':checked')) {
      // it is currently checked, un-ckeck it
      checkbox.prop("checked", false);
      $(this).removeClass('day-button-selected');
    } else {
      // it is currently un-checked, ckeck it
      checkbox.prop("checked", true);
      $(this).addClass('day-button-selected');
    }
  });

  $('.monthly_day_buttons label').on('click', function () {
    var checkbox = $(this).prev('input:checkbox:first');
    if (checkbox.is(':checked')) {
      // it is currently checked, un-ckeck it
      checkbox.prop("checked", false);
      $(this).removeClass('day-button-selected');
    } else {
      // it is currently un-checked, ckeck it
      checkbox.prop("checked", true);
      $(this).addClass('day-button-selected');
    }
  });

  $('.recurring_event_data input').on('change', function () {
    formUpdateHandler();
  });
  //$('.recurring_event_data input').on('input', function () {
  //  formUpdateHandler();
  //});
  $('.recurring_event_data label').on('click', function () {
    formUpdateHandler();
  });


  //
  // range_of_reccurence fields
  //
  $('.range_of_reccurence input').on('change', function () {
    formUpdateHandler();
  });
  //$('.range_of_reccurence input').on('input', function () {
  //  formUpdateHandler();
  //});


  // Submit button handler
  $('input[type=submit]').on('click', function () {
    submitButtonHandler();
  });

  // Initialise...
  formUpdateHandler();
});

$(function () {
  $(document).on("change", "select#resource_planner_event_rrule", function () {
    $("table.recurring_event_data").hide(); //'slow');
    $("table.range_of_reccurence").hide(); //'slow');

    var selected_recurrence = $("select#resource_planner_event_rrule").val();
    clearFields(selected_recurrence);       // clear all fields of previous screens...
    if (selected_recurrence) {
      $("table.recurring_event_data." + selected_recurrence).show(); //'slow');
      if (selected_recurrence !== "no_repeat") {
        $("table.range_of_reccurence").show(); //'slow');
      }
    }

    window.startingDate = $.trim($("#start_date").val());
    if (window.startingDate == "") {
      window.startingDate = moment().format();
      $.trim($("#start_date").val(moment(window.startingDate).format()));
    }
    window.endingDate = window.startingDate;
    updateTimelineDuration(window.startingDate, window.endingDate);
    //updateTimelineDuration(window.startingDate, window.endingDate);

    return false;
  });

  //$(".day_buttons").buttonset();

  /* commented out for test - 29.12.2018
  $(document).on("click", ".day_buttons label", function(event) {
    //alert($(this).text() + ' clicked');
    var checkbox = $(this).prev('input:checkbox:first');
    if (checkbox.is(':checked')) {
      checkbox.prop("checked", false);
      $(this).removeClass('day-button-selected');
    } else {
      checkbox.prop("checked", true);
      $(this).addClass('day-button-selected');
    }
    return false;
  });
  // commented out for test - 29.12.2018 */

  //$(document).on("change", ".day_buttons input", function(event) {
  //  alert($(this).is(':checked'));
  //  if ($(this).is(':checked')) {
  //    $(this).closest('label').addClass('day-button-selected');
  //  } else {
  //    $(this).closest('label').removeClass('day-button-selected');
  //  }
  //  return false;
  //});


  //$(".monthly_day_buttons").buttonset();
  /*
  $(document).on("click", ".monthly_day_buttons label", function(event) {
    //alert($(this).text() + ' clicked');
    var checkbox = $(this).prev('input:checkbox:first');
    if (checkbox.is(':checked')) {
      checkbox.prop("checked", false);
      $(this).removeClass('day-button-selected');
    } else {
      checkbox.prop("checked", true);
      $(this).addClass('day-button-selected');
    }
    return false;
  });
*/

  //$(document).on("change", ".monthly_day_buttons input", function(event) {
  //  alert($(this).is(':checked'));
  //  if ($(this).is(':checked')) {
  //    $(this).closest('label').addClass('day-button-selected');
  //  } else {
  //    $(this).closest('label').removeClass('day-button-selected');
  //  }
  //  return false;
  //});

});

// Capture form fields -> 'window' data
function formUpdateHandler() {
  captureFormData();
  //validateFormData();
  updateIcalData();
  //prepareEventsArray();
  //renderEvents();
}

/**
 * Capture form fields -> formData
 */
function captureFormData() {

  formData.title = $.trim($('#title').val());
  formData.description = $.trim($('#description').val());

  formData.start_date = $.trim($('#start_date').val());
  formData.resource_planner_event_dtstart_timezone = $.trim($('#resource_planner_event_dtstart_timezone').val());

  formData.duration = $.trim($('#duration').val());
  formData.duration_units = $.trim($('#duration_units').val());

  formData.resource_planner_event_rrule = $.trim($('#resource_planner_event_rrule').val());

  // no_repeat fields
  formData.end_date = $.trim($('#end_date').val());
  formData.resource_planner_event_dtend_timezone = $.trim($('#resource_planner_event_dtend_timezone').val());

  // daily fields
  formData.resource_planner_event_count_every_n_days = $('#resource_planner_event_count_every_n_days')[0].checked;
  formData.resource_planner_event_count_every_weekday = $('#resource_planner_event_count_every_weekday')[0].checked;
  formData.resource_planner_event_count = $.trim($('#resource_planner_event_count').val());

  // weekly fields
  //resource_planner_event_count (See above.... In the 'weekly' case, it always refers to 'every n weeks')
  var selected_weekdays = '';
  $('.recurring_event_data.weekly .day_buttons input[type=checkbox]').each(function (index) {
    if ($(this)[0].checked) {
      var name = $(this)[0].name;
      var day = name.substring(name.lastIndexOf("[") + 1, name.lastIndexOf("]"));
      selected_weekdays = selected_weekdays + day + '/';
    }
  });
  formData.selected_weekdays = selected_weekdays.substring(0, selected_weekdays.length - 1);


  // monthly fields
  formData.resource_planner_event_count_every_month = $('#resource_planner_event_count_every_month')[0].checked;
  //resource_planner_event_count (See above.... In the 'monthly' case, it always refers to 'every n months')
  formData.resource_planner_event_bymonthday = $.trim($('#resource_planner_event_bymonthday').val());
  formData.resource_planner_event_bymonthday_day = $.trim($('#resource_planner_event_bymonthday_day').val());

  formData.resource_planner_event_count_every_month_day = $('#resource_planner_event_count_every_month_day')[0].checked;
  var selected_days_of_month = '';
  $('.recurring_event_data.monthly .monthly_day_buttons input[type=checkbox]').each(function (index) {
    if ($(this)[0].checked) {
      var name = $(this)[0].name;
      var date = name.substring(name.lastIndexOf("[") + 1, name.lastIndexOf("]"));
      selected_days_of_month = selected_days_of_month + date + '/';
    }
  });
  formData.selected_days_of_month = selected_days_of_month.substring(0, selected_days_of_month.length - 1);


  // range_of_reccurence fields
  formData.resource_planner_event_until_no_end_date = $('#resource_planner_event_until_no_end_date')[0].checked;
  formData.resource_planner_event_until_create_n_events = $('#resource_planner_event_until_create_n_events')[0].checked;
  formData.resource_planner_event_until_count = $.trim($('#resource_planner_event_until_count').val());
  formData.resource_planner_event_until_repeat_until = $('#resource_planner_event_until_repeat_until')[0].checked;
  formData.repeat_until = $.trim($('#repeat_until').val());

  //console.clear();
  console.log('formData:');
  console.log(formData);
}

/**
 * Convert formData into iCalData
 */
function updateIcalData() {
  // This could be performed on the server-side
}

// Submit button
function submitButtonHandler() {
  // Show summary
  var msg = "Event will be created:\n" +
    "Start    :" + formData.start_date + "(" + window.startingDate + ")\n" +
    "End      :" + formData.end_date + "(" + window.endingDate + ")\n" +
    "Resources:\n" +
    selectedResources;
  alert(msg);
  //alertDialog.show(msg);

  var data = {};
  data.formData = formData;
  data.resources = selectedResources;
  data.eventsArray = eventsArray;

  // //Passing mdate and phone variables to rails controller(book_date & phone)
  // window.open("localhost:3000//controller/create?mdate="+mdate+"&phone="+phone,"_self")
  //
  // -- OR --
  //

  /* Send the data using an ajax-post */
  $.ajax({
    //headers: { 'X-CSRF-Token': $('meta[name="csrf-token"]').attr('content') },
    url: '/resource_planner/events',
    type: 'POST',
    data: JSON.stringify(data),
    //data: data,
    //dataType: 'json',
    contentType: 'application/json',
    success: function (data, textStatus, jqXHR) {
      //alert('Complete: ' + textStatus);
      $('#fullcalendar_scheduler').fullCalendar('rerenderEvents');
    },
    created: function (data, textStatus, jqXHR) {
      //alert('Complete: ' + textStatus);
      $('#fullcalendar_scheduler').fullCalendar('rerenderEvents');
    },
    ok: function (data, textStatus, jqXHR) {
      //alert('Complete: ' + textStatus);
      $('#fullcalendar_scheduler').fullCalendar('rerenderEvents');
    },
    done: function (data, textStatus, jqXHR) {
      //alert('Complete: ' + textStatus);
      $('#fullcalendar_scheduler').fullCalendar('rerenderEvents');
    },
    error: function (data, textStatus, jqXHR) {
      //alert('Error: ' + textStatus);
    },
  });

  //
  // -- OR --
  //
  // // construct an HTTP request
  // var xhr = new XMLHttpRequest();
  // xhr.open(form.method, form.action, true);
  // xhr.setRequestHeader('Content-Type', 'application/json; charset=UTF-8');
  //
  // // send the collected data as JSON
  // xhr.send(JSON.stringify(data));
  //
  // xhr.onloadend = function () {
  //   // done
  // };
  //

}


//================================================================================================
function clearFields(selected_recurrence) { // clear all fields of previous screens...

  $('.highlighter').remove();
  $('#highlighter').remove();

  window.startingDate = undefined;
  window.endingDate = undefined;
  window.eventsArray = [];

  //var start_date = new Date(start_date).yyyymmdd();
  var start_date = $.trim($("#start_date").val());
  if (start_date == "") {
    $("#start_date").addClass("input_warning");
  } else {
    $("#start_date").removeClass("input_warning");
  }

  $.trim($("#duration").val(""));
  if (selected_recurrence !== "no_repeat") {
    $("#duration").addClass("input_warning");
    $("table.range_of_reccurence").show(); //'slow');
  } else {
    $.trim($("#duration").val(""));
    $.trim($("#end_date").val(""));
    $("#duration").addClass("input_warning");
    $("#end_date").addClass("input_warning");
  }

  // Clear DAILY Fields
  var buttonChecked = $('.recurring_event_data.daily input#resource_planner_event_count_every_n_days');
  buttonChecked[0].checked = false;
  $('.recurring_event_data.daily input#resource_planner_event_count').val("");
  buttonChecked = $('.recurring_event_data.daily input#resource_planner_event_count_every_weekday');
  buttonChecked[0].checked = false;

  //$(".recurring_event_data.daily").removeClass("input_warning");
  $(".recurring_event_data.daily").addClass("input_warning");

  // Clear WEEKLY Fields
  $('.recurring_event_data.weekly input').val("");

  $('.recurring_event_data.weekly .day_buttons input[type=checkbox]').each(function (index) {
    $(this)[0].checked = false;
  });
  $('.day-button-selected').removeClass('day-button-selected');

  //$(".recurring_event_data.weekly").removeClass("input_warning");
  $(".recurring_event_data.weekly").addClass("input_warning");

  // Clear MONTHLY Fields
  buttonChecked = $('.recurring_event_data.monthly input#resource_planner_event_count_every_month');
  buttonChecked[0].checked = false;
  $('.recurring_event_data.monthly input#resource_planner_event_count').val("");
  var selectedCheckedButton = $('.recurring_event_data.monthly input#resource_planner_event_count_every_month_day');   // is the day_of_month button checked ?
  selectedCheckedButton[0].checked = false;

  $('.recurring_event_data.monthly .monthly_day_buttons input[type=checkbox]').each(function (index) {
    $(this)[0].checked = false;
  });
  var selectedMonthDays = $('.recurring_event_data.monthly label.day-button-selected');
  selectedMonthDays.removeClass('day-button-selected');

  //$(".recurring_event_data.monthly").removeClass("input_warning");
  $(".recurring_event_data.monthly").addClass("input_warning");

  document.getElementById("resource_planner_event_until_no_end_date").checked = false;
  document.getElementById("resource_planner_event_until_create_n_events").checked = false;
  $("#resource_planner_event_until_count").val("");
  //$("#repeat_until").val("");
  document.getElementById("resource_planner_event_until_repeat_until").checked = false;
  //$(".range_of_reccurence").removeClass("input_warning");
  $(".range_of_reccurence").addClass("input_warning");

}                                          // clear all fields of previous screens...
